
import bpy
import os


bl_info = {
    "name": "Rename",
    "author": "xz-blender rerpack",
    "version": (1, 0),
    "blender": (2, 80, 0),
    "location": "File > Rename Current File",
    "description": "Allows renaming the current Blender file",
    "warning": "",
    "doc_url": "https://blender4.com/about/",
    "category": "File",
}

class RenameCurrentFile(bpy.types.Operator):
    bl_idname = "file.rename_current_file"
    bl_label = "重命名当前文件"
    bl_description = "重命名当前的Blender文件"
    bl_options = {'REGISTER', 'UNDO'}

    # Property to store the new file name
    new_name: bpy.props.StringProperty(
        name="新的文件名",
        description="输入文件的新名称 (不带扩展名)",
        default=""
    ) # type: ignore

    def execute(self, context):
        # Check if the file is saved
        if not bpy.data.is_saved:
            self.report({'ERROR'}, "必须先保存文件!")
            return {'CANCELLED'}

        # Get the current file path and directory
        current_path = bpy.data.filepath
        directory = os.path.dirname(current_path)
        new_path = os.path.join(directory, self.new_name + ".blend")

        # Check if a file with the new name already exists
        if os.path.exists(new_path):
            self.report({'ERROR'}, "该名称的文件已存在!")
            return {'CANCELLED'}

        try:
            # Rename the file and save it with the new name
            os.rename(current_path, new_path)
            bpy.ops.wm.save_as_mainfile(filepath=new_path)
            self.report({'INFO'}, f"文件重命名为 {self.new_name}.blend")
        except Exception as e:
            self.report({'ERROR'}, f"重命名时出错: {str(e)}")
            return {'CANCELLED'}

        return {'FINISHED'}

    def invoke(self, context, event):
        # Show a dialog to input the new name
        return context.window_manager.invoke_props_dialog(self)

def menu_func(self, context):
    # Add the operator to the File menu
    self.layout.operator(RenameCurrentFile.bl_idname,icon = "SYNTAX_OFF")

def register():
    # Register the operator and add it to the File menu
    bpy.utils.register_class(RenameCurrentFile)
    bpy.types.TOPBAR_MT_file.append(menu_func)
    from pathlib import Path
    print(f"{Path(__file__).parent.name} 插件由xz-blender购买分享!感谢支持!")

def unregister():
    # Unregister the operator and remove it from the File menu
    bpy.utils.unregister_class(RenameCurrentFile)
    bpy.types.TOPBAR_MT_file.remove(menu_func)

if __name__ == "__main__":
    register()